#!/usr/bin/env python


import os
import sys
import hashlib
import base64
import string
import random
import string


def write_userfile(user,passwd):
  f = open("nmgrusers.list", "w")
  admuser = user+":all,rw:"+str(passwd)
  f.write(admuser)
  f.close()

passwd = 'ODNhMWZmNjAzOTk4'
upassw = base64.encodebytes(hashlib.md5(passwd.encode('utf-8')).digest()).decode()
write_userfile('nuhemgr',upassw)
